run

Function run 

pub(crate) async fn run(
    command: &Option<WorkerCommands>,
) -> Result<(), OperationOutcomeError>
Runs the worker command group. command is None when the bare worker invocation is used, which behaves the same as worker worker.